@@ -13,8 +13,8 @@
  *		See the LICENSE file at the top of the source tree.
  * \warning     File has been Lined up using 8 Space TABS
  *
- * $Date: 2014-06-27 15:39:53 +0200 (Fri, 27 Jun 2014) $
- * $Revision: 5531 $
+ * $Date: 2014-07-04 12:59:07 +0200 (Fri, 04 Jul 2014) $
+ * $Revision: 5574 $
  */
 
 #ifndef __CHAN_SCCP_H
@@ -260,7 +260,6 @@ typedef enum { FALSE = 0, TRUE = 1 } boolean_t;									/*!< Asterisk Reverses T
 #define TRUE B_TRUE
 #endif
 typedef void sk_func(sccp_device_t * d, sccp_line_t * l, sccp_channel_t * c);
-typedef enum { ANSWER_LAST_FIRST = 1, ANSWER_OLDEST_FIRST = 2 } call_answer_order_t;				/*!< Enum Call Answer Order */
 typedef enum { PARK_RESULT_FAIL = 0, PARK_RESULT_SUCCESS = 1 } sccp_parkresult_t;				/*!< Enum Park Result */
 typedef enum {
 	/* *INDENT-OFF* */
@@ -840,7 +839,6 @@ struct sccp_line {
 	boolean_t silencesuppression;										/*!< Silence Suppression Phone Support */
 	boolean_t meetme;											/*!< Meetme on/off */
 	boolean_t transfer;											/*!< Transfer Phone Support */
-	uint16_t dnd;												/*!< dnd on line */
 	uint16_t dndmode;											/*!< dnd mode: see SCCP_DNDMODE_* */
 
 	SCCP_LIST_HEAD (, sccp_mailbox_t) mailboxes;								/*!< Mailbox Linked List Entry. To check for messages */
@@ -1066,6 +1064,7 @@ struct sccp_device {
 	void (*setBackgroundImage) (const sccp_device_t * device, const char *url);				/*!< set device background image */
 	void (*displayBackgroundImagePreview) (const sccp_device_t * device, const char *url);			/*!< display background image as preview */
 	void (*setRingTone) (const sccp_device_t * device, const char *url);					/*!< set the default Ringtone */
+	sccp_dtmfmode_t (*getDtmfMode) (const sccp_device_t *device);
 
 	char *(messageStack[SCCP_MAX_MESSAGESTACK]);								/*!< Message Stack Array */
 #ifndef SCCP_ATOMIC
@@ -1196,6 +1195,7 @@ struct sccp_channel {
 	} enbloc;
 
 	struct {
+		boolean_t deny;
 		int digittimeout;										/*!< Schedule for Timeout on Dialing State */
 		int hangup;											/*!< Automatic hangup after invalid/congested indication */
 	} scheduler;
@@ -1286,7 +1286,7 @@ struct sccp_global_vars {
 	uint8_t transfer_tone;											/*!< Transfer Tone */
 	uint8_t callwaiting_tone;										/*!< Call Waiting Tone */
 	uint8_t callwaiting_interval;										/*!< Call Waiting Ring Interval */
-	uint8_t dndmode;											/*!< Do Not Disturb (DND) Mode: \see SCCP_DNDMODE_* */
+	boolean_t dndFeature;											/*!< Do Not Disturb (DND) Mode: \see SCCP_DNDMODE_* */
 	uint16_t protocolversion;										/*!< Skinny Protocol Version */
 	boolean_t transfer_on_hangup;										/*!< Complete transfer on hangup */
 
@@ -1309,7 +1309,7 @@ struct sccp_global_vars {
 	boolean_t privacy;											/*!< Privacy Support (Length=2) */
 	skinny_lampmode_t mwilamp;										/*!< MWI/Lamp (Length:3) */
 	boolean_t mwioncall;											/*!< MWI On Call Support (Boolean, default=on) */
-	boolean_t blindtransferindication;									/*!< Blind Transfer Indication Support (Boolean, default=on = SCCP_BLINDTRANSFER_MOH) */
+	sccp_blindtransferindication_t blindtransferindication;							/*!< Blind Transfer Indication Support (Boolean, default=on = SCCP_BLINDTRANSFER_MOH) */
 	boolean_t cfwdall;											/*!< Call Forward All Support (Boolean, default=on) */
 	boolean_t cfwdbusy;											/*!< Call Forward on Busy Support (Boolean, default=on) */
 	boolean_t cfwdnoanswer;											/*!< Call Forward on No-Answer Support (Boolean, default=on) */
@@ -1321,7 +1321,7 @@ struct sccp_global_vars {
 	sccp_group_t pickupgroup;										/*!< PickUp Group */
 	boolean_t directed_pickup_modeanswer;									/*!< Directed PickUp Mode Answer (boolean, default" on) */
 #endif
-	call_answer_order_t callanswerorder;									/*!< Call Answer Order */
+	sccp_call_answer_order_t callanswerorder;								/*!< Call Answer Order */
 	boolean_t meetme;											/*!< Meetme on/off */
 	char meetmeopts[SCCP_MAX_CONTEXT];									/*!< Meetme Options to be Used */
 	boolean_t allowAnonymous;										/*!< Allow Anonymous/Guest Devices */
