@@ -9,8 +9,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-07-02 19:35:43 +0200 (Wed, 02 Jul 2014) $
- * $Revision: 5559 $  
+ * $Date: 2014-08-04 16:45:09 +0200 (Mon, 04 Aug 2014) $
+ * $Revision: 5624 $  
  */
 #include <config.h>
 #include "../../common.h"
@@ -21,7 +21,7 @@
 #include "../../sccp_socket.h"
 #include "../../sccp_pbx.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5559 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5624 $")
 
 /*
  * \brief itterate through locked pbx channels
@@ -884,7 +884,7 @@ enum ast_pbx_result pbx_pbx_start (PBX_CHANNEL_TYPE *pbx_channel) {
 #endif		
 		// check if the pickup extension was entered
 		const char *dialedNumber = PBX(getChannelExten)(channel);
-		char *pickupexten = "";
+		char *pickupexten;
 		if (PBX(getPickupExtension)(channel, &pickupexten) && sccp_strequals(dialedNumber, pickupexten)) {
 			if (sccp_asterisk_doPickup(pbx_channel)) {
 				res = AST_PBX_SUCCESS;
@@ -907,7 +907,7 @@ enum ast_pbx_result pbx_pbx_start (PBX_CHANNEL_TYPE *pbx_channel) {
 				sccp_log(DEBUGCAT_PBX)(VERBOSE_PREFIX_3 "%s: (pbx_pbx_start) autoloop has started, set requestHangup = requestQueueHangup\n", channel->designator);
 				channel->hangupRequest = sccp_wrapper_asterisk_requestQueueHangup;
 			} else {
-				pbx_log(LOG_NOTICE, "%s: (pbx_pbx_start) autoloop is not running anymore, dummyHangup should remain. Will already be hungup/being hungup\n", channel->designator);
+				pbx_log(LOG_NOTICE, "%s: (pbx_pbx_start) autoloop is not running anymore, carefullHangup should remain. This channel will be hungup/being hungup soon\n", channel->designator);
 				res = AST_PBX_FAILED;
 			}
 		}
