@@ -6,8 +6,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2010-10-23 20:04:30 +0200 (Sat, 23 Oct 2010) $
- * $Revision: 2044 $  
+ * $Date: 2014-06-26 19:11:12 +0200 (Thu, 26 Jun 2014) $
+ * $Revision: 5524 $  
  */
 
 #ifndef SCCP_AST_MAJOR_H_
@@ -185,7 +185,7 @@ int pbx_manager_register(const char *action, int authority, int (*func) (struct
 		char idtext[256] = "";										\
 		int total = 0;											\
 		if (!pbx_strlen_zero(id)) {									\
-			snprintf(idtext, sizeof(idtext), "ActionID: %s\r\n", id);				\
+			snprintf(idtext, sizeof(idtext), "ActionID: %s", id);				\
 		}												\
 		if (RESULT_SUCCESS==_CALLED_FUNCTION(-1, &total, s, m, ARRAY_LEN(arguments), arguments)) {	\
 		        astman_send_ack(s, m, AMI_COMMAND);							\
@@ -193,7 +193,7 @@ int pbx_manager_register(const char *action, int authority, int (*func) (struct
                         astman_send_error(s, m, "Execution Failed\n");						\
                 }												\
 		astman_append(s,										\
-		"Event: " _DESCR " Complete\r\n"								\
+		"Event: " AMI_COMMAND "Complete\r\n"								\
 		"EventList: Complete\r\n"									\
 		"ListItems: %d\r\n"										\
 		"%s"												\
