@@ -4,8 +4,8 @@
  * \author	Marcello Ceschia <marcelloceschia [at] users.sorceforge.net>
  * \note	Reworked, but based on chan_sccp code.
  *
- * $Date: 2014-06-08 12:55:42 +0200 (Sun, 08 Jun 2014) $
- * $Revision: 5482 $
+ * $Date: 2014-08-07 15:24:35 +0200 (Thu, 07 Aug 2014) $
+ * $Revision: 5632 $
  */
 
 #include <config.h>
@@ -38,7 +38,7 @@
 #define sccp_participant_retain(_x) 	({ast_assert(_x != NULL);(sccp_conference_participant_t *)sccp_refcount_retain(_x, __FILE__, __LINE__, __PRETTY_FUNCTION__);})
 #define sccp_participant_release(_x) 	({ast_assert(_x != NULL);(sccp_conference_participant_t *)sccp_refcount_release(_x, __FILE__, __LINE__, __PRETTY_FUNCTION__);})
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5482 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5632 $")
 static int lastConferenceID = 99;
 static const uint32_t appID = APPID_CONFERENCE;
 
@@ -508,6 +508,9 @@ void sccp_conference_addParticipatingChannel(sccp_conference_t * conference, scc
 static void sccp_conference_removeParticipant(sccp_conference_t * conference, sccp_conference_participant_t * participant)
 {
 	sccp_conference_participant_t *tmp_participant = NULL;
+	if (!conference || !participant) {
+		return;
+	}
 
 	sccp_log((DEBUGCAT_CORE + DEBUGCAT_CONFERENCE)) (VERBOSE_PREFIX_4 "SCCPCONF/%04d: Removing Participant %d.\n", conference->id, participant->id);
 
@@ -544,7 +547,7 @@ static void sccp_conference_removeParticipant(sccp_conference_t * conference, sc
 static void *sccp_conference_thread(void *data)
 {
 	AUTO_RELEASE sccp_conference_participant_t *participant = sccp_participant_retain(data);
-	if (participant) {
+	if (participant && participant->conference && participant->conference->bridge) {
 		sccp_log_and((DEBUGCAT_CONFERENCE + DEBUGCAT_HIGH)) (VERBOSE_PREFIX_4 "SCCPCONF/%04d: entering join thread.\n", participant->conference->id);
 #ifdef CS_MANAGER_EVENTS
 		if (GLOB(callevents)) {
@@ -812,7 +815,7 @@ int playback_to_conference(sccp_conference_t * conference, const char *filename,
 	int res = 0;
 
 	if (!conference || !conference->playback_announcements) {
-		sccp_log((DEBUGCAT_CONFERENCE)) (VERBOSE_PREFIX_4 "SCCPCONF/%04d: Playback on conference suppressed\n", conference->id);
+		sccp_log((DEBUGCAT_CONFERENCE)) (VERBOSE_PREFIX_4 "SCCPCONF: Playback on conference suppressed\n");
 		return 1;
 	}
 
@@ -1183,7 +1186,7 @@ void sccp_conference_show_list(sccp_conference_t * conference, sccp_channel_t *
  */
 void __sccp_conference_hide_list(sccp_conference_participant_t * participant)
 {
-	if (participant->channel && participant->device) {
+	if (participant->channel && participant->device && participant->conference) {
 		if (participant->device->conferencelist_active) {
 			sccp_log((DEBUGCAT_CONFERENCE)) (VERBOSE_PREFIX_4 "SCCPCONF/%04d: Hide Conf List for participant: %d\n", participant->conference->id, participant->id);
 			char *data = "<CiscoIPPhoneExecute><ExecuteItem Priority=\"0\" URL=\"App:Close:0\"/></CiscoIPPhoneExecute>";
