@@ -15,8 +15,8 @@
  * Relations:	SCCP Device -> SCCP DeviceLine -> SCCP Line
  * 		SCCP Line -> SCCP ButtonConfig -> SCCP Device
  *
- * \date	$Date: 2014-07-04 00:07:29 +0200 (Fri, 04 Jul 2014) $
- * \version     $Revision: 5569 $
+ * \date	$Date: 2014-08-07 12:11:28 +0200 (Thu, 07 Aug 2014) $
+ * \version     $Revision: 5628 $
  */
 
 #include <config.h>
@@ -32,16 +32,16 @@
 #include "sccp_indicate.h"
 #include "sccp_mwi.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5569 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5628 $")
 int __sccp_device_destroy(const void *ptr);
 void sccp_device_removeFromGlobals(sccp_device_t * device);
 int sccp_device_destroy(const void *ptr);
 
 /* indicate definition */
-static void sccp_device_old_indicate_remoteHold(const sccp_device_t * device, uint8_t lineInstance, uint8_t callid, uint8_t callpriority, uint8_t callPrivacy);
-static void sccp_device_new_indicate_remoteHold(const sccp_device_t * device, uint8_t lineInstance, uint8_t callid, uint8_t callpriority, uint8_t callPrivacy);
-static void sccp_device_indicate_offhook(const sccp_device_t * device, sccp_linedevices_t * linedevice, uint8_t callid);
-static void sccp_device_indicate_onhook(const sccp_device_t * device, const sccp_channel_t *channel, const uint8_t lineInstance, uint8_t callid);
+static void sccp_device_old_indicate_remoteHold(const sccp_device_t * device, uint8_t lineInstance, uint32_t callid, uint8_t callpriority, uint8_t callPrivacy);
+static void sccp_device_new_indicate_remoteHold(const sccp_device_t * device, uint8_t lineInstance, uint32_t callid, uint8_t callpriority, uint8_t callPrivacy);
+static void sccp_device_indicate_offhook(const sccp_device_t * device, sccp_linedevices_t * linedevice, uint32_t callid);
+static void sccp_device_indicate_onhook(const sccp_device_t * device, const uint8_t lineInstance, uint32_t callid);
 static void sccp_device_indicate_dialing(const sccp_device_t * device, const uint8_t lineInstance, const sccp_channel_t * channel);
 static void sccp_device_indicate_proceed(const sccp_device_t * device, const uint8_t lineInstance, const sccp_channel_t * channel);
 static void sccp_device_indicate_connected(const sccp_device_t * device, sccp_linedevices_t * linedevice, const sccp_channel_t * channel);
@@ -750,6 +750,9 @@ void sccp_dev_build_buttontemplate(sccp_device_t * d, btnlist * btn)
 			/* add text message support */
 			d->pushTextMessage = sccp_device_pushTextMessage;
 			d->pushURL = sccp_device_pushURL;
+			d->setBackgroundImage = sccp_device_setBackgroundImage;
+			d->displayBackgroundImagePreview = sccp_device_displayBackgroundImagePreview;
+			d->setRingTone = sccp_device_setRingtone;
 
 			for (i = 6 + sccp_addons_taps(d); i > 0; i--) {
 				(btn++)->type = SCCP_BUTTONTYPE_MULTI;
@@ -843,6 +846,13 @@ void sccp_dev_build_buttontemplate(sccp_device_t * d, btnlist * btn)
 				(btn++)->type = SCCP_BUTTONTYPE_MULTI;
 			}
 			break;
+		case SKINNY_DEVICETYPE_SPA_509G:
+			for (i = 0; i < 12; i++) {
+				(btn++)->type = SCCP_BUTTONTYPE_MULTI;
+			}
+			(btn++)->type = SKINNY_BUTTONTYPE_VOICEMAIL;
+			(btn++)->type = SKINNY_BUTTONTYPE_HOLD;
+			break;
 		case SKINNY_DEVICETYPE_SPA_525G2:
 			for (i = 0; i < 8; i++) {
 				(btn++)->type = SCCP_BUTTONTYPE_MULTI;
@@ -854,10 +864,17 @@ void sccp_dev_build_buttontemplate(sccp_device_t * d, btnlist * btn)
 			(btn++)->type = SCCP_BUTTONTYPE_MULTI;
 			break;
 		case SKINNY_DEVICETYPE_CISCO6921:
+			d->hasDisplayPrompt = sccp_device_falseResult;
 			for (i = 0; i < 2; i++) {
 				(btn++)->type = SCCP_BUTTONTYPE_MULTI;
 			}
-			d->hasDisplayPrompt = sccp_device_falseResult;
+			//for (i = 0; i < 6; i++) {
+			//	(btn++)->type = SCCP_BUTTONTYPE_SPEEDDIAL;
+			//}
+			//(btn++)->type = SKINNY_BUTTONTYPE_NONE;
+			//(btn++)->type = SKINNY_BUTTONTYPE_PRIVACY;
+			//(btn++)->type = SKINNY_BUTTONTYPE_DO_NOT_DISTURB;
+			//(btn++)->type = SKINNY_BUTTONTYPE_HLOG;			// hunt group logout
 			break;
 		case SKINNY_DEVICETYPE_CISCO6941:
 		case SKINNY_DEVICETYPE_CISCO6945:
@@ -1009,15 +1026,38 @@ void sccp_dev_set_keyset(const sccp_device_t * d, uint8_t lineInstance, uint32_t
 	if (!d->softkeysupport) {
 		return;												/* the device does not support softkeys */
 	}
-	/*let's activate the transfer */
-	if (softKeySetIndex == KEYMODE_CONNECTED) {
-		softKeySetIndex = 
-				(
+	/* 69XX Exception SoftKeySet Mapping */
+	if (	d->skinny_type == SKINNY_DEVICETYPE_CISCO6901 || 
+		d->skinny_type == SKINNY_DEVICETYPE_CISCO6911 ||
+		d->skinny_type == SKINNY_DEVICETYPE_CISCO6921 ||
+		d->skinny_type == SKINNY_DEVICETYPE_CISCO6941 ||
+		d->skinny_type == SKINNY_DEVICETYPE_CISCO6945 ||
+		d->skinny_type == SKINNY_DEVICETYPE_CISCO6961) {
+
+		/* 69XX does not like CONNCONF, so let's not set that and keep CONNECTED instead */
+		/* while transfer in progress, they like OFFHOOKFEAT, after when we have connected to the destination we need to set CONNTRANS */
+		/*! \todo Discuss if this behaviour should not be the general case for all devices */
+		if (d->transfer && d->transferChannels.transferee) {
+			/* first stage transfer */
+			if (softKeySetIndex == KEYMODE_OFFHOOK  && !d->transferChannels.transferer){
+				softKeySetIndex = KEYMODE_OFFHOOKFEAT;
+			}
+			/* second stage transfer (blind or not)*/
+			if ((softKeySetIndex == KEYMODE_RINGOUT || softKeySetIndex == KEYMODE_CONNECTED) && d->transferChannels.transferer) {
+				softKeySetIndex = KEYMODE_CONNTRANS;
+			}
+		}
+	} else {
+		/*let's replace the CONNECTED with the transfer / conference states when allowed on this device */
+		if (softKeySetIndex == KEYMODE_CONNECTED) {
+			softKeySetIndex = 
+					(
 #if CS_SCCP_CONFERENCE
-					  (d->conference) ? KEYMODE_CONNCONF :
+						  (d->conference) ? KEYMODE_CONNCONF :
 #endif
-					  (d->transfer) ? KEYMODE_CONNTRANS : KEYMODE_CONNECTED
-				);
+						  (d->transfer) ? KEYMODE_CONNTRANS : KEYMODE_CONNECTED
+					);
+		}
 	}
 	REQ(msg, SelectSoftKeysMessage);
 	if (!msg) {
@@ -2310,7 +2350,7 @@ void sccp_dev_keypadbutton(sccp_device_t * d, char digit, uint8_t line, uint32_t
 /*!
  * \brief Indicate to device that remote side has been put on hold (old).
  */
-static void sccp_device_old_indicate_remoteHold(const sccp_device_t * device, uint8_t lineInstance, uint8_t callid, uint8_t callpriority, uint8_t callPrivacy)
+static void sccp_device_old_indicate_remoteHold(const sccp_device_t * device, uint8_t lineInstance, uint32_t callid, uint8_t callpriority, uint8_t callPrivacy)
 {
 	sccp_device_sendcallstate(device, lineInstance, callid, SKINNY_CALLSTATE_HOLD, callpriority, callPrivacy);
 	sccp_dev_set_keyset(device, lineInstance, callid, KEYMODE_ONHOLD);
@@ -2320,14 +2360,14 @@ static void sccp_device_old_indicate_remoteHold(const sccp_device_t * device, ui
 /*!
  * \brief Indicate to device that remote side has been put on hold (new).
  */
-static void sccp_device_new_indicate_remoteHold(const sccp_device_t * device, uint8_t lineInstance, uint8_t callid, uint8_t callpriority, uint8_t callPrivacy)
+static void sccp_device_new_indicate_remoteHold(const sccp_device_t * device, uint8_t lineInstance, uint32_t callid, uint8_t callpriority, uint8_t callPrivacy)
 {
 	sccp_device_sendcallstate(device, lineInstance, callid, SKINNY_CALLSTATE_HOLDRED, callpriority, callPrivacy);
 	sccp_dev_set_keyset(device, lineInstance, callid, KEYMODE_ONHOLD);
 	sccp_dev_displayprompt(device, lineInstance, callid, SKINNY_DISP_HOLD, GLOB(digittimeout));
 }
 
-static void sccp_device_indicate_offhook(const sccp_device_t * device, sccp_linedevices_t * linedevice, uint8_t callid)
+static void sccp_device_indicate_offhook(const sccp_device_t * device, sccp_linedevices_t * linedevice, uint32_t callid)
 {
 
 	sccp_dev_set_speaker(device, SKINNY_STATIONSPEAKER_ON);
@@ -2338,19 +2378,18 @@ static void sccp_device_indicate_offhook(const sccp_device_t * device, sccp_line
 	sccp_dev_starttone(device, SKINNY_TONE_INSIDEDIALTONE, linedevice->lineInstance, callid, 0);
 }
 
-static void sccp_device_indicate_onhook(const sccp_device_t * device, const sccp_channel_t *channel, const uint8_t lineInstance, uint8_t callid)
+#if 0	/* new impl: does not seem to work (Reported by Sharan and Antonio: 01-07-2014), needs more work */
+static void sccp_device_indicate_onhook(const sccp_device_t * device, const sccp_channel_t *channel, const uint8_t lineInstance, uint32_t callid)
 {
 	sccp_dev_stoptone(device, lineInstance, callid);
 	sccp_device_setLamp(device, SKINNY_STIMULUS_LINE, lineInstance, SKINNY_LAMP_OFF);
 
-/*new*/	// sccp_dev_cleardisplayprinotify(device);					/* not sure */
 	sccp_dev_cleardisplaynotify(device);
 	sccp_dev_clearprompt(device, lineInstance, callid);
-/*new*/	// sccp_dev_clearprompt(device, 0, 0);						/* already performed by sccp_dev_check_displayprompt */
-/*new*/	sccp_dev_cleardisplay(device);
+	sccp_dev_cleardisplay(device);
 
 	if (channel && channel->answered_elsewhere) {
-		sccp_device_sendcallstate(device, lineInstance, channel->callid, SKINNY_CALLSTATE_CONNECTED, SKINNY_CALLPRIORITY_LOW, SKINNY_CALLINFO_VISIBILITY_HIDDEN);
+		sccp_device_sendcallstate(device, lineInstance, callid, SKINNY_CALLSTATE_CONNECTED, SKINNY_CALLPRIORITY_LOW, SKINNY_CALLINFO_VISIBILITY_HIDDEN);
 	}
 
 	sccp_dev_set_ringer(device, SKINNY_RINGTYPE_OFF, lineInstance, callid);
@@ -2365,6 +2404,24 @@ static void sccp_device_indicate_onhook(const sccp_device_t * device, const sccp
 	sccp_device_clearMessageFromStack((sccp_device_t *)device, SCCP_MESSAGE_PRIORITY_PRIVACY);
 	sccp_dev_check_displayprompt(device);						/* see if we need to display anything from the messageStack */
 }
+#endif
+static void sccp_device_indicate_onhook(const sccp_device_t * device, const uint8_t lineInstance, uint32_t callid)
+{
+	sccp_dev_stoptone(device, lineInstance, callid);
+	sccp_dev_cleardisplaynotify(device);
+	sccp_dev_clearprompt(device, lineInstance, callid);
+	sccp_dev_cleardisplay(device);
+	//sccp_device_sendcallstate(d, instance, c->callid, SKINNY_CALLSTATE_CONNECTED, SKINNY_CALLPRIORITY_LOW, SKINNY_CALLINFO_VISIBILITY_HIDDEN);	/** if channel was answered somewhere, set state to connected before onhook -> no missedCalls entry */
+
+	sccp_dev_set_ringer(device, SKINNY_RINGTYPE_OFF, lineInstance, callid);
+	sccp_device_sendcallstate(device, lineInstance, callid, SKINNY_CALLSTATE_ONHOOK, SKINNY_CALLPRIORITY_LOW, SKINNY_CALLINFO_VISIBILITY_DEFAULT);
+	sccp_dev_set_cplane(device, lineInstance, 0);
+	sccp_dev_set_keyset(device, lineInstance, callid, KEYMODE_ONHOOK);
+	sccp_handle_time_date_req(device->session, (sccp_device_t *)device, NULL);	/** we need datetime on hangup for 7936 */
+	sccp_device_clearMessageFromStack((sccp_device_t *)device, SCCP_MESSAGE_PRIORITY_PRIVACY);
+	sccp_dev_check_displayprompt(device);						/* see if we need to display anything from the messageStack */
+	sccp_dev_set_speaker(device, SKINNY_STATIONSPEAKER_OFF);
+}
 
 static void sccp_device_indicate_offhook_remote(const sccp_device_t * device, sccp_linedevices_t * linedevice, const sccp_channel_t * channel){
 	sccp_device_sendcallstate(device, linedevice->lineInstance, channel->callid, SKINNY_CALLSTATE_OFFHOOK, SKINNY_CALLPRIORITY_LOW, SKINNY_CALLINFO_VISIBILITY_DEFAULT);
@@ -2397,18 +2454,33 @@ static void sccp_device_indicate_connected(const sccp_device_t * device, sccp_li
 	sccp_dev_displayprompt(device, linedevice->lineInstance, channel->callid, SKINNY_DISP_CONNECTED, GLOB(digittimeout));
 }
 
+/*!
+ * \todo sccp_device_indicate_dialing should be split in a early_immediate version and a standard version, to make this function more readable. We can bind the correct indication function during device
+ * registration / sccp_channel_setDevice
+ */
 static void sccp_device_indicate_dialing(const sccp_device_t * device, const uint8_t lineInstance, const sccp_channel_t * channel){
-	sccp_dev_stoptone(device, lineInstance, channel->callid);
+	if (device->earlyrtp != SCCP_EARLYRTP_IMMEDIATE) {/* The dialtone has not been played, not necessary to stop it then */
+		sccp_dev_stoptone(device, lineInstance, channel->callid);
+	}
 	sccp_device_setLamp(device, SKINNY_STIMULUS_LINE, lineInstance, SKINNY_LAMP_BLINK);
+	if (!(device->earlyrtp == SCCP_EARLYRTP_IMMEDIATE)) {
+		sccp_channel_t *c = (sccp_channel_t *) channel;		/* ugly/temp solution to get rid of const */
+		sccp_channel_set_calledparty(c, c->dialedNumber, c->dialedNumber);
+		sccp_device_sendcallstate(device, lineInstance, channel->callid, SKINNY_CALLSTATE_PROCEED, SKINNY_CALLPRIORITY_LOW, SKINNY_CALLINFO_VISIBILITY_DEFAULT);
+	}
 	if (device->protocol) {
 		if (device->protocol->sendDialedNumber) {
 			device->protocol->sendDialedNumber(device, channel);
 		}
-		if (device->protocol->sendCallInfo) {
+		if (device->protocol->sendCallInfo && (device->protocol->version < 22 || (device->earlyrtp != SCCP_EARLYRTP_IMMEDIATE))) {
 			device->protocol->sendCallInfo(device, channel, lineInstance);
 		}
 	}
-	sccp_dev_set_keyset(device, lineInstance, channel->callid, KEYMODE_DIGITSFOLL);
+	if (device->earlyrtp == SCCP_EARLYRTP_IMMEDIATE) {
+		sccp_dev_set_keyset(device, lineInstance, channel->callid, KEYMODE_DIGITSFOLL);
+	} else {     
+		sccp_dev_set_keyset(device, lineInstance, channel->callid, KEYMODE_RINGOUT);
+	}
 }
 
 static void sccp_device_indicate_proceed(const sccp_device_t * device, const uint8_t lineInstance, const sccp_channel_t * channel){
