@@ -6,8 +6,8 @@
  *		See the LICENSE file at the top of the source tree.
  * \since	2013-08-15
  *
- * $Date: 2014-06-09 12:20:17 +0200 (Mon, 09 Jun 2014) $
- * $Revision: 5485 $  
+ * $Date: 2014-08-07 15:25:25 +0200 (Thu, 07 Aug 2014) $
+ * $Revision: 5633 $  
  */ 
 
 #include <config.h>
@@ -98,7 +98,7 @@ static void sccp_devstate_deviceRegistered(const sccp_device_t * device)
 
 	AUTO_RELEASE sccp_device_t *d = sccp_device_retain((sccp_device_t *) device);
 	if (d) {
-		SCCP_LIST_TRAVERSE(&device->buttonconfig, config, list) {
+		SCCP_LIST_TRAVERSE(&d->buttonconfig, config, list) {
 
 			if (config->type == FEATURE && config->button.feature.id == SCCP_FEATURE_DEVSTATE) {
 			  
@@ -122,7 +122,7 @@ static void sccp_devstate_deviceUnRegistered(const sccp_device_t * device)
 
 	AUTO_RELEASE sccp_device_t *d = sccp_device_retain((sccp_device_t *) device);
 	if (d) {
-		SCCP_LIST_TRAVERSE(&device->buttonconfig, config, list) {
+		SCCP_LIST_TRAVERSE(&d->buttonconfig, config, list) {
 
 			if (config->type == FEATURE && config->button.feature.id == SCCP_FEATURE_DEVSTATE) {
 			  
