@@ -8,8 +8,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-04-12 17:50:07 +0200 (Sat, 12 Apr 2014) $
- * $Revision: 5343 $
+ * $Date: 2014-07-08 12:32:21 +0200 (Tue, 08 Jul 2014) $
+ * $Revision: 5589 $
  */
 
 #ifndef _SCCP_DLLISTS_H
@@ -377,7 +377,7 @@ struct {												\
 	for((var) = (head)->first; (var); (var) = (var)->field.next) {					\
 	        if ((var) && compare) {									\
 	        	if (retain) {									\
-		                (var) = (var) ? sccp_refcount_retain((var), __FILE__, __LINE__, __PRETTY_FUNCTION__) : NULL;	\
+		                sccp_refcount_retain((var), __FILE__, __LINE__, __PRETTY_FUNCTION__);	\
 			}										\
 			break;										\
 	        }											\
