@@ -7,8 +7,8 @@
  *		See the LICENSE file at the top of the source tree.
  * \since	2009-09-02
  * 
- * $Date: 2014-04-24 14:14:40 +0200 (Thu, 24 Apr 2014) $
- * $Revision: 5387 $  
+ * $Date: 2014-06-06 11:56:09 +0200 (Fri, 06 Jun 2014) $
+ * $Revision: 5473 $  
  */
 
 /*!
@@ -24,11 +24,14 @@
 #include "sccp_device.h"
 #include "sccp_line.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5387 $")
-#define GENERATE_ENUM_STRINGS
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5473 $")
+
+#define ENUMMACRO_FILE "sccp_event_enums.hh"
+#define ENUMMACRO_GENERATE ENUMMACRO_GENFUNCTION
 #include "sccp_enum_macro.h"
-#include "sccp_event_enums.hh"
-#undef GENERATE_ENUM_STRINGS
+#undef  ENUMMACRO_GENERATE
+#undef  ENUMMACRO_FILE
+
 void sccp_event_destroy(sccp_event_t * event);
 
 /*!
@@ -83,29 +86,27 @@ void sccp_event_destroy(sccp_event_t * event)
 		case SCCP_EVENT_LINE_CHANGED:
 		case SCCP_EVENT_LINE_DELETED:
 			break;
+		case sccp_event_type_LOOKUPERROR:
+			break;
 	}
 //	pbx_log(LOG_NOTICE, "Event destroyed- %p type: %d\n", event, event->type);
 }
 
 static void *sccp_event_processor(void *data)
 {
-	struct sccp_event_aSyncEventProcessorThreadArg *args;
-	const struct sccp_event_subscriptions *subscribers;
-	sccp_event_t *event = NULL;
+	struct sccp_event_aSyncEventProcessorThreadArg *args = data;
+	const struct sccp_event_subscriptions *subscribers = args->subscribers;
+	AUTO_RELEASE sccp_event_t *event = sccp_event_retain(args->event);
 	int n;
 
-	args = data;
-	subscribers = args->subscribers;
-
-	if ((event = sccp_event_retain(args->event))) {
-		sccp_log((DEBUGCAT_EVENT)) (VERBOSE_PREFIX_3 "Processing Asynchronous Event %p of Type %s\n", event, event_type2str(event->type));
+	if (subscribers && event) {
+		sccp_log((DEBUGCAT_EVENT)) (VERBOSE_PREFIX_3 "Processing Asynchronous Event %p of Type %s\n", event, sccp_event_type2str(event->type));
 		for (n = 0; n < subscribers->aSyncSize && sccp_event_running; n++) {
 			if (subscribers->async[n].callback_function != NULL) {
-				sccp_log((DEBUGCAT_EVENT)) (VERBOSE_PREFIX_3 "Processing Event %p of Type %s: %p (%d)\n", event, event_type2str(event->type), subscribers->async[n].callback_function, n);
+				sccp_log((DEBUGCAT_EVENT)) (VERBOSE_PREFIX_3 "Processing Event %p of Type %s: %p (%d)\n", event, sccp_event_type2str(event->type), subscribers->async[n].callback_function, n);
 				subscribers->async[n].callback_function((const sccp_event_t *) event);
 			}
 		}
-		sccp_event_release(event);
 	} else {
 		sccp_log((DEBUGCAT_EVENT)) (VERBOSE_PREFIX_3 "Could not retain event\n");
 	}
@@ -218,7 +219,6 @@ void sccp_event_unsubscribe(sccp_event_type_t eventType, sccp_event_callback_t c
  */
 void sccp_event_fire(const sccp_event_t * event)
 {
-	sccp_event_t *tmp_e = NULL;
 	if (event == NULL || SCCP_REF_RUNNING != sccp_refcount_isRunning() || !sccp_event_running) {
 		if (event) {
 			sccp_event_destroy((sccp_event_t *)event);
@@ -226,7 +226,7 @@ void sccp_event_fire(const sccp_event_t * event)
 		return;
 	}
 
-	sccp_event_t *e = (sccp_event_t *) sccp_refcount_object_alloc(sizeof(sccp_event_t), SCCP_REF_EVENT, event_type2str(event->type), sccp_event_destroy);
+	AUTO_RELEASE sccp_event_t *e = (sccp_event_t *) sccp_refcount_object_alloc(sizeof(sccp_event_t), SCCP_REF_EVENT, sccp_event_type2str(event->type), sccp_event_destroy);
 	
 	if (!e) {
 		pbx_log(LOG_ERROR, "%p: Memory Allocation Error while creating sccp_event e. Exiting\n", event);
@@ -236,7 +236,7 @@ void sccp_event_fire(const sccp_event_t * event)
 	// memcpy(e, event, sizeof(sccp_event_t));
 	e->type = event->type;
 
-	sccp_log((DEBUGCAT_EVENT)) (VERBOSE_PREFIX_3 "Handling Event %p of Type %s\n", event, event_type2str(e->type));
+	sccp_log((DEBUGCAT_EVENT)) (VERBOSE_PREFIX_3 "Handling Event %p of Type %s\n", event, sccp_event_type2str(e->type));
 	/* update refcount */
 	switch (e->type) {
 		case SCCP_EVENT_DEVICE_REGISTERED:
@@ -269,6 +269,8 @@ void sccp_event_fire(const sccp_event_t * event)
 		case SCCP_EVENT_LINE_CHANGED:
 		case SCCP_EVENT_LINE_DELETED:
 			break;
+		case sccp_event_type_LOOKUPERROR:
+			break;
 	}
 
 	/* search for position in array */
@@ -298,33 +300,34 @@ void sccp_event_fire(const sccp_event_t * event)
 
 				/* initialized with default attributes */
 				if (arg->event != NULL) {
-					sccp_log((DEBUGCAT_EVENT)) (VERBOSE_PREFIX_3 "Adding work to threadpool for event: %p, type: %s\n", event, event_type2str(event->type));
+					sccp_log((DEBUGCAT_EVENT)) (VERBOSE_PREFIX_3 "Adding work to threadpool for event: %p, type: %s\n", event, sccp_event_type2str(event->type));
 					if (!sccp_threadpool_add_work(GLOB(general_threadpool), (void *) sccp_event_processor, (void *) arg)) {
-						pbx_log(LOG_ERROR, "Could not add work to threadpool for event: %p, type: %s for processing\n", event, event_type2str(event->type));
+						pbx_log(LOG_ERROR, "Could not add work to threadpool for event: %p, type: %s for processing\n", event, sccp_event_type2str(event->type));
 						arg->event = sccp_event_release(arg->event);
 						sccp_free(arg);
 					}
 				} else {
-					pbx_log(LOG_ERROR, "Could not retain e: %p, type: %s for processing\n", e, event_type2str(event->type));
+					pbx_log(LOG_ERROR, "Could not retain e: %p, type: %s for processing\n", e, sccp_event_type2str(event->type));
 					sccp_free(arg);
 				}
 			}
 		}
 
 		/* execute sync subscribers */
+		AUTO_RELEASE sccp_event_t *tmp_e = NULL;
 		if ((tmp_e = sccp_event_retain(e))) {
 			for (n = 0; n < subscriptions[i].syncSize && sccp_event_running; n++) {
 				if (subscriptions[i].sync[n].callback_function != NULL) {
 					subscriptions[i].sync[n].callback_function((const sccp_event_t *) e);
 				}
 			}
-			sccp_event_release(tmp_e);
 		} else {
-			pbx_log(LOG_ERROR, "Could not retain e: %p, type: %s for processing\n", e, event_type2str(event->type));
+			pbx_log(LOG_ERROR, "Could not retain e: %p, type: %s for processing\n", e, sccp_event_type2str(event->type));
 		}
 	} else {
 		// we are unloading. switching to synchonous mode for everything
-		sccp_log((DEBUGCAT_EVENT)) (VERBOSE_PREFIX_3 "Handling Event %p of Type %s in Forced Synchronous Mode\n", event, event_type2str(e->type));
+		sccp_log((DEBUGCAT_EVENT)) (VERBOSE_PREFIX_3 "Handling Event %p of Type %s in Forced Synchronous Mode\n", event, sccp_event_type2str(e->type));
+		AUTO_RELEASE sccp_event_t *tmp_e = NULL;
 		if ((tmp_e = sccp_event_retain(e))) {
 			for (n = 0; n < subscriptions[i].syncSize && sccp_event_running; n++) {
 				if (subscriptions[i].sync[n].callback_function != NULL) {
@@ -336,10 +339,8 @@ void sccp_event_fire(const sccp_event_t * event)
 					subscriptions[i].async[n].callback_function((const sccp_event_t *) e);
 				}
 			}
-			sccp_event_release(tmp_e);
 		} else {
-			pbx_log(LOG_ERROR, "Could not retain e: %p, type: %s for processing\n", e, event_type2str(event->type));
+			pbx_log(LOG_ERROR, "Could not retain e: %p, type: %s for processing\n", e, sccp_event_type2str(event->type));
 		}
 	}
-	sccp_event_release(e);
 }
