@@ -6,8 +6,8 @@
  * 		See the LICENSE file at the top of the source tree.
  * \since	2009-01-16
  *
- * $Date: 2014-07-02 19:24:24 +0200 (Wed, 02 Jul 2014) $
- * $Revision: 5558 $
+ * $Date: 2014-08-04 17:15:38 +0200 (Mon, 04 Aug 2014) $
+ * $Revision: 5625 $
  */
 
 /*!
@@ -35,7 +35,7 @@
 #include "sccp_indicate.h"
 #include "sccp_rtp.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5558 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5625 $")
 
 /*!
  * \brief Handle Call Forwarding
@@ -130,6 +130,7 @@ void sccp_feat_handle_callforward(sccp_line_t * l, sccp_device_t * device, sccp_
 				c->ss_action = SCCP_SS_GETFORWARDEXTEN;						/* Simpleswitch will catch a number to be dialed */
 				c->ss_data = type;								/* this should be found in thread */
 				// changing channelstate to GETDIGITS
+				sccp_indicate(device, c, SCCP_CHANNELSTATE_OFFHOOK);
 				sccp_indicate(device, c, SCCP_CHANNELSTATE_GETDIGITS);
 				return;
 			} else {
@@ -475,6 +476,7 @@ int sccp_feat_grouppickup(sccp_line_t * l, sccp_device_t * d)
 		sccp_copy_string(c->dialedNumber, pickupexten, sizeof(pickupexten));
 		sccp_pbx_softswitch(c);
 		sccp_log((DEBUGCAT_CORE)) (VERBOSE_PREFIX_3 "%s: (grouppickup) finished\n", DEV_ID_LOG(d));
+		sccp_free(pickupexten);
 		res = 0;
 	}
 #else
