@@ -8,8 +8,8 @@
  *		Modified by Jan Czmok and Julien Goodwin
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *
- * $Date: 2014-06-28 18:41:40 +0200 (Sat, 28 Jun 2014) $
- * $Revision: 5537 $
+ * $Date: 2014-08-07 12:11:28 +0200 (Thu, 07 Aug 2014) $
+ * $Revision: 5628 $
  */
 
 #include <config.h>
@@ -22,7 +22,7 @@
 #include "sccp_conference.h"
 #include "sccp_actions.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5537 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5628 $")
 
 static void __sccp_indicate_remote_device(sccp_device_t * device, sccp_channel_t * c, sccp_line_t * line, uint8_t state);
 
@@ -89,7 +89,8 @@ void __sccp_indicate(sccp_device_t * device, sccp_channel_t * c, sccp_channelsta
 				sccp_dev_set_cplane(d, instance, 1);
 				sccp_dev_displayprompt(d, instance, c->callid, SKINNY_DISP_ENTER_NUMBER, GLOB(digittimeout));
 				sccp_dev_set_keyset(d, instance, c->callid, KEYMODE_OFFHOOK);
-				sccp_dev_starttone(d, SKINNY_TONE_INSIDEDIALTONE, instance, c->callid, 0);
+				if (d->earlyrtp != SCCP_EARLYRTP_IMMEDIATE)
+					sccp_dev_starttone(d, SKINNY_TONE_INSIDEDIALTONE, instance, c->callid, 0);
 			} else {										// call pickup
 				sccp_dev_set_speaker(d, SKINNY_STATIONSPEAKER_ON);
 				sccp_device_setLamp(d, SKINNY_STIMULUS_LINE, instance, SKINNY_LAMP_ON);
@@ -128,7 +129,26 @@ void __sccp_indicate(sccp_device_t * device, sccp_channel_t * c, sccp_channelsta
 			break;
 		case SCCP_CHANNELSTATE_ONHOOK:
 			c->state = SCCP_CHANNELSTATE_DOWN;
-			d->indicate->onhook(d, c, instance, c->callid);
+			//d->indicate->onhook(d, c, instance, c->callid);			// reverted to old code, new one does not seem to work
+			sccp_dev_stoptone(d, instance, c->callid);
+			sccp_device_setLamp(d, SKINNY_STIMULUS_LINE, instance, SKINNY_LAMP_OFF);
+			sccp_dev_cleardisplaynotify(d);
+			sccp_dev_clearprompt(d, instance, c->callid);
+
+			/** if channel was answered somewhere, set state to connected before onhook -> no missedCalls entry */
+			if (c->answered_elsewhere) {
+				sccp_device_sendcallstate(d, instance, c->callid, SKINNY_CALLSTATE_CONNECTED, SKINNY_CALLPRIORITY_LOW, SKINNY_CALLINFO_VISIBILITY_HIDDEN);
+			}
+
+			sccp_dev_set_ringer(d, SKINNY_RINGTYPE_OFF, instance, c->callid);
+			sccp_device_sendcallstate(d, instance, c->callid, SKINNY_CALLSTATE_ONHOOK, SKINNY_CALLPRIORITY_LOW, SKINNY_CALLINFO_VISIBILITY_DEFAULT);
+			sccp_dev_set_cplane(d, instance, 0);
+			sccp_dev_set_keyset(d, instance, c->callid, KEYMODE_ONHOOK);
+
+			sccp_handle_time_date_req(d->session, d, NULL);	/** we need datetime on hangup for 7936 */
+			if (c == d->active_channel) {
+				sccp_dev_set_speaker(d, SKINNY_STATIONSPEAKER_OFF);
+			}
 			break;
 		case SCCP_CHANNELSTATE_RINGOUT:
 			sccp_device_sendcallstate(d, instance, c->callid, SKINNY_CALLSTATE_RINGOUT, SKINNY_CALLPRIORITY_LOW, SKINNY_CALLINFO_VISIBILITY_DEFAULT);
@@ -192,12 +212,12 @@ void __sccp_indicate(sccp_device_t * device, sccp_channel_t * c, sccp_channelsta
 			if (linedevice) {
 				d->indicate->connected(d, linedevice, c);
 			}
-			sccp_dev_set_keyset(d, instance, c->callid, KEYMODE_CONNECTED);
 			if (!c->rtp.audio.rtp || c->previousChannelState == SCCP_CHANNELSTATE_HOLD || c->previousChannelState == SCCP_CHANNELSTATE_CALLTRANSFER || c->previousChannelState == SCCP_CHANNELSTATE_CALLCONFERENCE || c->previousChannelState == SCCP_CHANNELSTATE_OFFHOOK) {
 				sccp_channel_openReceiveChannel(c);
 			} else if (c->rtp.audio.rtp) {
 				sccp_log((DEBUGCAT_RTP)) (VERBOSE_PREFIX_3 "%s: Did not reopen an RTP stream as old SCCP state was (%s)\n", d->id, sccp_channelstate2str(c->previousChannelState));
 			}
+			sccp_dev_set_keyset(d, instance, c->callid, KEYMODE_CONNECTED);
 			break;
 		case SCCP_CHANNELSTATE_BUSY:
 			if (!c->rtp.audio.rtp) {
@@ -243,10 +263,10 @@ void __sccp_indicate(sccp_device_t * device, sccp_channel_t * c, sccp_channelsta
 			sccp_handle_time_date_req(d->session, d, NULL);
 			sccp_device_setLamp(d, SKINNY_STIMULUS_LINE, instance, SKINNY_LAMP_WINK);
 			sccp_device_sendcallstate(d, instance, c->callid, SKINNY_CALLSTATE_HOLD, SKINNY_CALLPRIORITY_LOW, SKINNY_CALLINFO_VISIBILITY_DEFAULT);	/* send connected, so it is not listed as missed call */
-			sccp_dev_set_keyset(d, instance, c->callid, KEYMODE_ONHOLD);
 			sccp_dev_displayprompt(d, instance, c->callid, SKINNY_DISP_HOLD, GLOB(digittimeout));
 			d->protocol->sendCallInfo(d, c, instance);
 			sccp_dev_set_speaker(d, SKINNY_STATIONSPEAKER_OFF);
+			sccp_dev_set_keyset(d, instance, c->callid, KEYMODE_ONHOLD);
 			break;
 		case SCCP_CHANNELSTATE_CONGESTION:
 			/* it will be emulated if the rtp audio stream is open */
@@ -299,6 +319,18 @@ void __sccp_indicate(sccp_device_t * device, sccp_channel_t * c, sccp_channelsta
 			break;
 		case SCCP_CHANNELSTATE_CONNECTEDCONFERENCE:
 			sccp_log((DEBUGCAT_INDICATE)) (VERBOSE_PREFIX_3 "%s: SCCP_CHANNELSTATE_CONNECTEDCONFERENCE (%s)\n", d->id, sccp_channelstate2str(c->previousChannelState));
+/*
+			sccp_dev_set_ringer(d, SKINNY_RINGTYPE_OFF, instance, c->callid);
+			sccp_dev_set_speaker(d, SKINNY_STATIONSPEAKER_ON);
+			sccp_dev_stoptone(d, instance, c->callid);
+			sccp_device_setLamp(d, SKINNY_STIMULUS_LINE, instance, SKINNY_LAMP_ON);
+			sccp_device_sendcallstate(d, instance, c->callid, SKINNY_CALLSTATE_CONNECTED, SKINNY_CALLPRIORITY_LOW, SKINNY_CALLINFO_VISIBILITY_DEFAULT);
+			d->protocol->sendCallInfo(d, c, instance);
+			sccp_dev_set_cplane(d, instance, 1);
+			sccp_dev_set_keyset(d, instance, c->callid, KEYMODE_CONNCONF);
+			sccp_dev_displayprompt(d, instance, c->callid, SKINNY_DISP_CONNECTED, GLOB(digittimeout));
+*/
+// replaced by
 			if (linedevice) {
 				d->indicate->connected(d, linedevice, c);
 			}
