@@ -11,8 +11,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-06-28 18:41:40 +0200 (Sat, 28 Jun 2014) $
- * $Revision: 5537 $  
+ * $Date: 2014-07-10 13:40:46 +0200 (Thu, 10 Jul 2014) $
+ * $Revision: 5597 $  
  */
 
 #ifndef __SCCP_LABELS_H
@@ -458,5 +458,7 @@ static const struct skinny_label {
 #define SKINNY_DISP_USE							"use"
 #define SKINNY_DISP_PRIVATE_FEATURE_NOT_ACTIVE				"Private Feature is not active"
 #define SKINNY_DISP_PRIVATE_WITHOUT_LINE_CHANNEL			"Private without line or channel"
+#define SKINNY_DISP_NO_CHANNEL_TO_PERFORM_XXXXXXX_ON			"No Channel to perform %s on !"
+#define SKINNY_GIVING_UP						"Giving Up"
 
 #endif
