@@ -7,8 +7,8 @@
  * \note                This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *              See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-07-01 21:35:30 +0200 (Tue, 01 Jul 2014) $
- * $Revision: 5546 $
+ * $Date: 2014-07-19 16:39:52 +0200 (Sat, 19 Jul 2014) $
+ * $Revision: 5602 $
  */
 
 #include <config.h>
@@ -318,7 +318,7 @@ static void sccp_protocol_sendDialedNumberV19(const sccp_device_t * device, cons
 /*!
  * \brief Send Display Prompt Message (Static)
  */
-static void sccp_protocol_sendStaticDisplayprompt(const sccp_device_t * device, uint8_t lineInstance, uint8_t callid, uint8_t timeout, const char *message)
+static void sccp_protocol_sendStaticDisplayprompt(const sccp_device_t * device, uint8_t lineInstance, uint32_t callid, uint8_t timeout, const char *message)
 {
 	sccp_msg_t *msg;
 
@@ -335,7 +335,7 @@ static void sccp_protocol_sendStaticDisplayprompt(const sccp_device_t * device,
 /*!
  * \brief Send Display Prompt Message (Dynamic)
  */
-static void sccp_protocol_sendDynamicDisplayprompt(const sccp_device_t * device, uint8_t lineInstance, uint8_t callid, uint8_t timeout, const char *message)
+static void sccp_protocol_sendDynamicDisplayprompt(const sccp_device_t * device, uint8_t lineInstance, uint32_t callid, uint8_t timeout, const char *message)
 {
 	sccp_msg_t *msg;
 
@@ -575,7 +575,7 @@ static void sccp_protocol_sendOpenReceiveChannelV3(const sccp_device_t * device,
 	msg->data.OpenReceiveChannel.v3.lel_payloadType = htolel(channel->rtp.audio.writeFormat);
 	msg->data.OpenReceiveChannel.v3.lel_vadValue = htolel(channel->line->echocancel);
 	msg->data.OpenReceiveChannel.v3.lel_callReference = htolel(channel->callid);
-	msg->data.OpenReceiveChannel.v3.lel_remotePortNumber = htolel(4000);
+//	msg->data.OpenReceiveChannel.v3.lel_remotePortNumber = htolel(4000);
 	if (SCCP_DTMFMODE_SKINNY == channel->dtmfmode) {
 		msg->data.OpenReceiveChannel.v3.lel_RFC2833Type = htolel(0);
 	} else {
@@ -583,6 +583,15 @@ static void sccp_protocol_sendOpenReceiveChannelV3(const sccp_device_t * device,
 	}
 	msg->data.OpenReceiveChannel.v3.lel_dtmfType = htolel(10);;
 
+	/* Source Ip Address */
+	struct sockaddr_storage sas;
+	memcpy(&sas, &channel->rtp.audio.phone_remote, sizeof(struct sockaddr_storage));
+	sccp_socket_ipv4_mapped(&sas, &sas);
+
+       	struct sockaddr_in *in = (struct sockaddr_in *)&sas;
+       	memcpy(&msg->data.OpenReceiveChannel.v3.bel_remoteIpAddr, &in->sin_addr, 4);
+	msg->data.OpenReceiveChannel.v3.lel_remotePortNumber = htolel(sccp_socket_getPort(&sas));
+
 	sccp_dev_send(device, msg);
 }
 
@@ -600,7 +609,6 @@ static void sccp_protocol_sendOpenReceiveChannelV17(const sccp_device_t * device
 	msg->data.OpenReceiveChannel.v17.lel_payloadType = htolel(channel->rtp.audio.writeFormat);
 	msg->data.OpenReceiveChannel.v17.lel_vadValue = htolel(channel->line->echocancel);
 	msg->data.OpenReceiveChannel.v17.lel_callReference = htolel(channel->callid);
-//	msg->data.OpenReceiveChannel.v17.lel_remotePortNumber = htolel(4000);
 	if (SCCP_DTMFMODE_SKINNY == channel->dtmfmode) {
 		msg->data.OpenReceiveChannel.v17.lel_RFC2833Type = htolel(0);
 	} else {
@@ -608,6 +616,7 @@ static void sccp_protocol_sendOpenReceiveChannelV17(const sccp_device_t * device
 	}
 	msg->data.OpenReceiveChannel.v17.lel_dtmfType = htolel(10);;
 
+	/* Source Ip Address */
 	struct sockaddr_storage sas;
 //	memcpy(&sas, &device->session->sin, sizeof(struct sockaddr_storage));
 	memcpy(&sas, &channel->rtp.audio.phone_remote, sizeof(struct sockaddr_storage));
@@ -640,7 +649,6 @@ static void sccp_protocol_sendOpenReceiveChannelv22(const sccp_device_t * device
 	msg->data.OpenReceiveChannel.v22.lel_payloadType = htolel(channel->rtp.audio.writeFormat);
 	msg->data.OpenReceiveChannel.v22.lel_vadValue = htolel(channel->line->echocancel);
 	msg->data.OpenReceiveChannel.v22.lel_callReference = htolel(channel->callid);
-//	msg->data.OpenReceiveChannel.v22.lel_remotePortNumber = htolel(4000);
 	if (SCCP_DTMFMODE_SKINNY == channel->dtmfmode) {
 		msg->data.OpenReceiveChannel.v22.lel_RFC2833Type = htolel(0);
 	} else {
@@ -648,6 +656,7 @@ static void sccp_protocol_sendOpenReceiveChannelv22(const sccp_device_t * device
 	}
 	msg->data.OpenReceiveChannel.v22.lel_dtmfType = htolel(10);;
 
+	/* Source Ip Address */
 	struct sockaddr_storage sas;
 //	memcpy(&sas, &device->session->sin, sizeof(struct sockaddr_storage));
 	memcpy(&sas, &channel->rtp.audio.phone_remote, sizeof(struct sockaddr_storage));
@@ -746,7 +755,6 @@ static void sccp_protocol_sendStartMediaTransmissionV3(const sccp_device_t * dev
 	msg->data.StartMediaTransmission.v3.lel_precedenceValue = htolel(device->audio_tos);
 	msg->data.StartMediaTransmission.v3.lel_ssValue = htolel(channel->line->silencesuppression);		// Silence supression
 	msg->data.StartMediaTransmission.v3.lel_maxFramesPerPacket = htolel(0);
-	msg->data.StartMediaTransmission.v3.lel_remotePortNumber = htolel(sccp_socket_getPort(&channel->rtp.audio.phone_remote) );
 	if (SCCP_DTMFMODE_SKINNY == channel->dtmfmode) {
 		msg->data.StartMediaTransmission.v3.lel_RFC2833Type = htolel(0);
 	} else {
@@ -760,6 +768,8 @@ static void sccp_protocol_sendStartMediaTransmissionV3(const sccp_device_t * dev
 	}else {
 		/* \todo add warning */
 	}
+	msg->data.StartMediaTransmission.v3.lel_remotePortNumber = htolel(sccp_socket_getPort(&channel->rtp.audio.phone_remote) );
+
 	sccp_dev_send(device, msg);
 }
 
@@ -779,7 +789,6 @@ static void sccp_protocol_sendStartMediaTransmissionV17(const sccp_device_t * de
 	msg->data.StartMediaTransmission.v17.lel_precedenceValue = htolel(device->audio_tos);
 	msg->data.StartMediaTransmission.v17.lel_ssValue = htolel(channel->line->silencesuppression);		// Silence supression
 	msg->data.StartMediaTransmission.v17.lel_maxFramesPerPacket = htolel(0);
-	msg->data.StartMediaTransmission.v17.lel_remotePortNumber = htolel( sccp_socket_getPort(&channel->rtp.audio.phone_remote) );
 	if (SCCP_DTMFMODE_SKINNY == channel->dtmfmode) {
 		msg->data.StartMediaTransmission.v17.lel_RFC2833Type = htolel(0);
 	} else {
@@ -795,6 +804,7 @@ static void sccp_protocol_sendStartMediaTransmissionV17(const sccp_device_t * de
 		struct sockaddr_in *in = (struct sockaddr_in *)&channel->rtp.audio.phone_remote;
 		memcpy(&msg->data.StartMediaTransmission.v17.bel_remoteIpAddr, &in->sin_addr, 4);
 	}
+	msg->data.StartMediaTransmission.v17.lel_remotePortNumber = htolel( sccp_socket_getPort(&channel->rtp.audio.phone_remote) );
 	sccp_dev_send(device, msg);
 }
 
@@ -820,7 +830,6 @@ static void sccp_protocol_sendStartMediaTransmissionv22(const sccp_device_t * de
 		msg->data.StartMediaTransmission.v22.lel_RFC2833Type = htolel(101);
 	}
 	msg->data.StartMediaTransmission.v22.lel_dtmfType = htolel(10);;
-	msg->data.StartMediaTransmission.v22.lel_remotePortNumber = htolel( sccp_socket_getPort(&channel->rtp.audio.phone_remote) );
 	        
 	if (channel->rtp.audio.phone_remote.ss_family == AF_INET6) {
 		struct sockaddr_in6 *in6 = (struct sockaddr_in6 *)&channel->rtp.audio.phone_remote;
@@ -830,6 +839,7 @@ static void sccp_protocol_sendStartMediaTransmissionv22(const sccp_device_t * de
 		struct sockaddr_in *in = (struct sockaddr_in *)&channel->rtp.audio.phone_remote;
 		memcpy(&msg->data.StartMediaTransmission.v22.bel_remoteIpAddr, &in->sin_addr, 4);
 	}
+	msg->data.StartMediaTransmission.v22.lel_remotePortNumber = htolel( sccp_socket_getPort(&channel->rtp.audio.phone_remote) );
 	sccp_dev_send(device, msg);
 }
 
@@ -1148,7 +1158,7 @@ static void sccp_protocol_parseStartMultiMediaTransmissionAckV17(const sccp_msg_
 	*callID1 = letohl(msg->data.StartMultiMediaTransmissionAck.v17.lel_callReference1);
 	*mediastatus = letohl(msg->data.StartMultiMediaTransmissionAck.v17.lel_mediastatus);
 
-	if (letohl(msg->data.StartMultiMediaTransmissionAck.v17.lel_ipv46) == 0) {				// read ipv4 address
+	if (letohl(msg->data.StartMultiMediaTransmissionAck.v17.lel_ipv46) == 0) {			// read ipv4 address
 		ss->ss_family = AF_INET;
 		struct sockaddr_in *sin = (struct sockaddr_in *)ss;
 		memcpy(&sin->sin_addr, &msg->data.StartMultiMediaTransmissionAck.v17.bel_ipAddr, INET_ADDRSTRLEN);
@@ -1165,19 +1175,25 @@ static void sccp_protocol_parseStartMultiMediaTransmissionAckV17(const sccp_msg_
 /*!
  * \brief EnblocCallMessage
  */
+static void sccp_protocol_parseEnblocCallV3(const sccp_msg_t * msg, char *calledParty, uint32_t *lineInstance)
+{
+	sccp_copy_string(calledParty, msg->data.EnblocCallMessage.v3.calledParty, StationMaxDirnumSize);
+	*lineInstance = 0;										// v3 - v16 don't provicde lineInstance during enbloc dialing
+}
+
 static void sccp_protocol_parseEnblocCallV17(const sccp_msg_t * msg, char *calledParty, uint32_t *lineInstance)
 {
-	sccp_copy_string(calledParty, msg->data.EnblocCallMessage.v18.calledParty, StationMaxDirnumSize);
-	*lineInstance = letohl(msg->data.EnblocCallMessage.v18.lel_lineInstance);
+	sccp_copy_string(calledParty, msg->data.EnblocCallMessage.v17.calledParty, StationMaxDirnumSize);
+	*lineInstance = letohl(msg->data.EnblocCallMessage.v17.lel_lineInstance);
 }
 
 static void sccp_protocol_parseEnblocCallV22(const sccp_msg_t * msg, char *calledParty, uint32_t *lineInstance)
 {
-	sccp_copy_string(calledParty, msg->data.EnblocCallMessage.v22.calledParty, 25);
+	sccp_copy_string(calledParty, msg->data.EnblocCallMessage.v18.calledParty, 25);
 #if defined(HAVE_UNALIGNED_BUSERROR)
-	*lineInstance = letohl(get_unaligned_uint32(msg->data.EnblocCallMessage.v22.lel_lineInstance));
+	*lineInstance = letohl(get_unaligned_uint32(msg->data.EnblocCallMessage.v18.lel_lineInstance));
 #else
-	*lineInstance = letohl(msg->data.EnblocCallMessage.v22.lel_lineInstance);
+	*lineInstance = letohl(msg->data.EnblocCallMessage.v18.lel_lineInstance);
 #endif
 }
 
@@ -1192,32 +1208,32 @@ static const sccp_deviceProtocol_t *sccpProtocolDefinition[] = {
 	NULL,
 	&(sccp_deviceProtocol_t) {"SCCP", 3, TimeDateReqMessage, sccp_device_sendCallinfoV3, sccp_protocol_sendDialedNumberV3, sccp_protocol_sendRegisterAckV3, sccp_protocol_sendStaticDisplayprompt, sccp_protocol_sendStaticDisplayNotify, sccp_protocol_sendStaticDisplayPriNotify, sccp_protocol_sendCallForwardStatus, sccp_protocol_sendUserToDeviceDataVersion1Message, sccp_protocol_sendFastPictureUpdate, sccp_protocol_sendOpenReceiveChannelV3, sccp_protocol_sendOpenMultiMediaChannelV3,
 				  sccp_protocol_sendStartMultiMediaTransmissionV3, sccp_protocol_sendStartMediaTransmissionV3,
-				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, NULL},	/* default impl */
+				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, sccp_protocol_parseEnblocCallV3},	/* default impl */
 	NULL,
 	&(sccp_deviceProtocol_t) {"SCCP", 5, TimeDateReqMessage, sccp_device_sendCallinfoV3, sccp_protocol_sendDialedNumberV3, sccp_protocol_sendRegisterAckV4, sccp_protocol_sendStaticDisplayprompt, sccp_protocol_sendStaticDisplayNotify, sccp_protocol_sendStaticDisplayPriNotify, sccp_protocol_sendCallForwardStatus, sccp_protocol_sendUserToDeviceDataVersion1Message, sccp_protocol_sendFastPictureUpdate, sccp_protocol_sendOpenReceiveChannelV3, sccp_protocol_sendOpenMultiMediaChannelV3,
 				  sccp_protocol_sendStartMultiMediaTransmissionV3, sccp_protocol_sendStartMediaTransmissionV3,
-				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, NULL},
+				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, sccp_protocol_parseEnblocCallV3},
 	NULL,
 	NULL,
 	NULL,
 	&(sccp_deviceProtocol_t) {"SCCP", 9, TimeDateReqMessage, sccp_device_sendCallinfoV7, sccp_protocol_sendDialedNumberV3, sccp_protocol_sendRegisterAckV4, sccp_protocol_sendDynamicDisplayprompt, sccp_protocol_sendDynamicDisplayNotify, sccp_protocol_sendDynamicDisplayPriNotify, sccp_protocol_sendCallForwardStatus, sccp_protocol_sendUserToDeviceDataVersion1Message, sccp_protocol_sendFastPictureUpdate, sccp_protocol_sendOpenReceiveChannelV3, sccp_protocol_sendOpenMultiMediaChannelV3,
 				  sccp_protocol_sendStartMultiMediaTransmissionV3, sccp_protocol_sendStartMediaTransmissionV3,
-				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, NULL},
+				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, sccp_protocol_parseEnblocCallV3},
 	&(sccp_deviceProtocol_t) {"SCCP", 10, TimeDateReqMessage, sccp_device_sendCallinfoV7, sccp_protocol_sendDialedNumberV3, sccp_protocol_sendRegisterAckV4, sccp_protocol_sendDynamicDisplayprompt, sccp_protocol_sendDynamicDisplayNotify, sccp_protocol_sendDynamicDisplayPriNotify, sccp_protocol_sendCallForwardStatus, sccp_protocol_sendUserToDeviceDataVersion1Message, sccp_protocol_sendFastPictureUpdate, sccp_protocol_sendOpenReceiveChannelV3, sccp_protocol_sendOpenMultiMediaChannelV3,
 				  sccp_protocol_sendStartMultiMediaTransmissionV3, sccp_protocol_sendStartMediaTransmissionV3,
-				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, NULL},
+				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, sccp_protocol_parseEnblocCallV3},
 	&(sccp_deviceProtocol_t) {"SCCP", 11, TimeDateReqMessage, sccp_device_sendCallinfoV7, sccp_protocol_sendDialedNumberV3, sccp_protocol_sendRegisterAckV11, sccp_protocol_sendDynamicDisplayprompt, sccp_protocol_sendDynamicDisplayNotify, sccp_protocol_sendDynamicDisplayPriNotify, sccp_protocol_sendCallForwardStatus, sccp_protocol_sendUserToDeviceDataVersion1Message, sccp_protocol_sendFastPictureUpdate, sccp_protocol_sendOpenReceiveChannelV3, sccp_protocol_sendOpenMultiMediaChannelV3,
 				  sccp_protocol_sendStartMultiMediaTransmissionV3, sccp_protocol_sendStartMediaTransmissionV3,
-				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, NULL},
+				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, sccp_protocol_parseEnblocCallV3},
 	NULL,
 	NULL,
 	NULL,
 	&(sccp_deviceProtocol_t) {"SCCP", 15, TimeDateReqMessage, sccp_device_sendCallinfoV7, sccp_protocol_sendDialedNumberV3, sccp_protocol_sendRegisterAckV11, sccp_protocol_sendDynamicDisplayprompt, sccp_protocol_sendDynamicDisplayNotify, sccp_protocol_sendDynamicDisplayPriNotify, sccp_protocol_sendCallForwardStatus, sccp_protocol_sendUserToDeviceDataVersion1Message, sccp_protocol_sendFastPictureUpdate, sccp_protocol_sendOpenReceiveChannelV3, sccp_protocol_sendOpenMultiMediaChannelV17,
 				  sccp_protocol_sendStartMultiMediaTransmissionV17, sccp_protocol_sendStartMediaTransmissionV3,
-				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, NULL},
+				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, sccp_protocol_parseEnblocCallV3},
 	&(sccp_deviceProtocol_t) {"SCCP", 16, TimeDateReqMessage, sccp_protocol_sendCallinfoV16, sccp_protocol_sendDialedNumberV3, sccp_protocol_sendRegisterAckV11, sccp_protocol_sendDynamicDisplayprompt, sccp_protocol_sendDynamicDisplayNotify, sccp_protocol_sendDynamicDisplayPriNotify, sccp_protocol_sendCallForwardStatus, sccp_protocol_sendUserToDeviceDataVersion1Message, sccp_protocol_sendFastPictureUpdate, sccp_protocol_sendOpenReceiveChannelV3, sccp_protocol_sendOpenMultiMediaChannelV17,
 				  sccp_protocol_sendStartMultiMediaTransmissionV17, sccp_protocol_sendStartMediaTransmissionV3,
-				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, NULL},
+				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, sccp_protocol_parseEnblocCallV3},
 	&(sccp_deviceProtocol_t) {"SCCP", 17, TimeDateReqMessage, sccp_protocol_sendCallinfoV16, sccp_protocol_sendDialedNumberV3, sccp_protocol_sendRegisterAckV11, sccp_protocol_sendDynamicDisplayprompt, sccp_protocol_sendDynamicDisplayNotify, sccp_protocol_sendDynamicDisplayPriNotify, sccp_protocol_sendCallForwardStatus, sccp_protocol_sendUserToDeviceDataVersion1Message, sccp_protocol_sendFastPictureUpdate, sccp_protocol_sendOpenReceiveChannelV17, sccp_protocol_sendOpenMultiMediaChannelV17,
 				  sccp_protocol_sendStartMultiMediaTransmissionV17, sccp_protocol_sendStartMediaTransmissionV17,
 				  sccp_protocol_parseOpenReceiveChannelAckV17, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV17, sccp_protocol_parseStartMediaTransmissionAckV17, sccp_protocol_parseStartMultiMediaTransmissionAckV17, sccp_protocol_parseEnblocCallV17},
@@ -1261,7 +1277,7 @@ static const sccp_deviceProtocol_t *sccpProtocolDefinition[] = {
 static const sccp_deviceProtocol_t *spcpProtocolDefinition[] = {
 	&(sccp_deviceProtocol_t) {"SPCP", 0, RegisterAvailableLinesMessage, sccp_device_sendCallinfoV3, sccp_protocol_sendDialedNumberV3, sccp_protocol_sendRegisterAckV4, sccp_protocol_sendDynamicDisplayprompt, sccp_protocol_sendDynamicDisplayNotify, sccp_protocol_sendDynamicDisplayPriNotify, sccp_protocol_sendCallForwardStatus, sccp_protocol_sendUserToDeviceDataVersion1Message, sccp_protocol_sendFastPictureUpdate, sccp_protocol_sendOpenReceiveChannelV3, sccp_protocol_sendOpenMultiMediaChannelV3,
 				  sccp_protocol_sendStartMultiMediaTransmissionV3, sccp_protocol_sendStartMediaTransmissionV3,
-				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3},
+				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, sccp_protocol_parseEnblocCallV3},
 	NULL,
 	NULL,
 	NULL,
@@ -1271,7 +1287,7 @@ static const sccp_deviceProtocol_t *spcpProtocolDefinition[] = {
 	NULL,
 	&(sccp_deviceProtocol_t) {"SPCP", 8, RegisterAvailableLinesMessage, sccp_device_sendCallinfoV3, sccp_protocol_sendDialedNumberV3, sccp_protocol_sendRegisterAckV4, sccp_protocol_sendDynamicDisplayprompt, sccp_protocol_sendDynamicDisplayNotify, sccp_protocol_sendDynamicDisplayPriNotify, sccp_protocol_sendCallForwardStatus, sccp_protocol_sendUserToDeviceDataVersion1Message, sccp_protocol_sendFastPictureUpdate, sccp_protocol_sendOpenReceiveChannelV3, sccp_protocol_sendOpenMultiMediaChannelV3,
 				  sccp_protocol_sendStartMultiMediaTransmissionV3, sccp_protocol_sendStartMediaTransmissionV3,
-				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3},
+				  sccp_protocol_parseOpenReceiveChannelAckV3, sccp_protocol_parseOpenMultiMediaReceiveChannelAckV3, sccp_protocol_parseStartMediaTransmissionAckV3, sccp_protocol_parseStartMultiMediaTransmissionAckV3, sccp_protocol_parseEnblocCallV17},
 };
 
 /*! 
