@@ -8,8 +8,8 @@
  * \note                This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *              See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-07-03 23:41:19 +0200 (Thu, 03 Jul 2014) $
- * $Revision: 5566 $
+ * $Date: 2014-07-30 12:48:28 +0200 (Wed, 30 Jul 2014) $
+ * $Revision: 5617 $
  */
 
 #include <netinet/in.h>
@@ -19,7 +19,7 @@
 #include "sccp_device.h"
 #include "sccp_utils.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5566 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5617 $")
 #ifndef CS_USE_POLL_COMPAT
 #include <poll.h>
 #include <sys/poll.h>
@@ -85,9 +85,13 @@ int sccp_socket_is_any_addr(const struct sockaddr_storage *sockAddrStorage)
 	    (sccp_socket_is_IPv6(sockAddrStorage) && IN6_IS_ADDR_UNSPECIFIED(&tmp_addr.sin6.sin6_addr));
 }
 
-boolean_t sccp_socket_getExternalAddr(struct sockaddr_storage *sockAddrStorage, sa_family_t type)
+boolean_t sccp_socket_getExternalAddr(struct sockaddr_storage *sockAddrStorage)
 {    
-	//! \todo handle type parameter
+	//! \todo handle IPv4 / IPV6 family ?
+	if (sccp_socket_is_any_addr(&GLOB(externip))) {
+		sccp_log(DEBUGCAT_CORE)(VERBOSE_PREFIX_3 "SCCP: No externip set in sccp.conf. In case you are running your PBX on a seperate host behind a NATTED Firewall you need to set externip.\n");
+		return FALSE;
+	}
 	memcpy(sockAddrStorage, &GLOB(externip), sizeof(struct sockaddr_storage));
 	return TRUE;
 }
