@@ -8,8 +8,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-02-02 16:12:28 +0100 (Sun, 02 Feb 2014) $
- * $Revision: 5102 $  
+ * $Date: 2014-07-24 17:56:33 +0200 (Thu, 24 Jul 2014) $
+ * $Revision: 5607 $  
  */
 
 #ifndef __SCCP_SOCKET_H
@@ -20,7 +20,7 @@ boolean_t sccp_socket_is_IPv6(const struct sockaddr_storage *sockAddrStorage);
 uint16_t sccp_socket_getPort(const struct sockaddr_storage *sockAddrStorage);
 void sccp_socket_setPort(const struct sockaddr_storage *sockAddrStorage, uint16_t port);
 int sccp_socket_is_any_addr(const struct sockaddr_storage *sockAddrStorage);
-boolean_t sccp_socket_getExternalAddr(struct sockaddr_storage *sockAddrStorage, sa_family_t type);
+boolean_t sccp_socket_getExternalAddr(struct sockaddr_storage *sockAddrStorage);
 int sccp_socket_getOurAddressfor(const struct sockaddr_storage *them, struct sockaddr_storage *us);
 size_t sccp_socket_sizeof(const struct sockaddr_storage *sockAddrStorage);
 boolean_t sccp_socket_is_mapped_IPv4(const struct sockaddr_storage *sockAddrStorage);
