@@ -9,8 +9,8 @@
  * \note	This program is free software and may be modified and distributed under the terms of the GNU Public License.
  *		See the LICENSE file at the top of the source tree.
  *
- * $Date: 2014-07-02 14:34:16 +0200 (Wed, 02 Jul 2014) $
- * $Revision: 5556 $
+ * $Date: 2014-07-07 11:57:12 +0200 (Mon, 07 Jul 2014) $
+ * $Revision: 5586 $
  */
 
 #include <config.h>
@@ -26,7 +26,7 @@
 #include "sccp_actions.h"
 #include "sccp_rtp.h"
 
-SCCP_FILE_VERSION(__FILE__, "$Revision: 5556 $")
+SCCP_FILE_VERSION(__FILE__, "$Revision: 5586 $")
 
 /* private prototypes */
 void sccp_sk_videomode(sccp_device_t * d, sccp_line_t * l, const uint32_t lineInstance, sccp_channel_t * c);
@@ -413,21 +413,23 @@ void sccp_sk_endcall(sccp_device_t * d, sccp_line_t * l, const uint32_t lineInst
 		return;
 	}
 	
-//	if (c->calltype == SKINNY_CALLTYPE_INBOUND && 1 < c->subscribers--) { // && pbx_channel_state(c->owner) != AST_STATE_UP) {
-//		if (d && d->indicate && d->indicate->onhook) {
-//			d->indicate->onhook(d, c, lineInstance, c->callid);
-//		}
-//	} else {
-//		sccp_channel_endcall(c);
-//	}
+	if (c->calltype == SKINNY_CALLTYPE_INBOUND && 1 < c->subscribers--) { // && pbx_channel_state(c->owner) != AST_STATE_UP) {
+		if (d && d->indicate && d->indicate->onhook) {
+			d->indicate->onhook(d, lineInstance, c->callid);
+		}
+	} else {
+		sccp_channel_endcall(c);
+	}
 
+#if 0 /* new */
 	if (!(c->calltype == SKINNY_CALLTYPE_INBOUND && 1 < c->subscribers--)) {
 		sccp_channel_endcall(c);
 	}
 	if (d && d->indicate && d->indicate->onhook) {
-		sccp_indicate(d, c, SCCP_CHANNELSTATE_ONHOOK);
-		//d->indicate->onhook(d, c, lineInstance, c->callid);
+		//sccp_indicate(d, c, SCCP_CHANNELSTATE_ONHOOK);
+		d->indicate->onhook(d, lineInstance, c->callid);
 	}
+#endif
 }
 
 /*!
